@@ -232,6 +232,7 @@ sub get_all_accounts {
         $self->exec_method(funcname => 'payment_get_all_accounts');
     return @{$self->{accounts}};
 }
+
 =over
 
 =item $payment->reverse()
@@ -414,7 +415,7 @@ The list is attached to $self->{departments} and returned.
 =cut
 
 =over
-                      
+
 =item get_open_currencies
 
 This method gets a list of the open currencies inside the database, it requires that  
@@ -432,14 +433,15 @@ sub get_open_currencies {
   return @{$self->{openCurrencies}};
 }
 
-
 =over
 
 =item list_accounting
 
 This method lists all accounts that match the role specified in account_class property and
 are available to store the payment or receipts. 
+
 =back
+
 =cut
 
 sub list_accounting {
@@ -448,11 +450,15 @@ sub list_accounting {
  return @{$self->{pay_accounts}}; 
 }
 
+=over
+
 =item list_overpayment_accounting
 
 This method lists all accounts that match the role specified in account_class property and
 are available to store an overpayment / advanced payment / pre-payment. 
+
 =back
+
 =cut
 
 sub list_overpayment_accounting {
@@ -461,11 +467,13 @@ sub list_overpayment_accounting {
  return @{$self->{overpayment_accounts}}; 
 }
 
+=over
 
 =item get_sources
 
 This method builds all the possible sources of money,
 in the future it will look inside the DB. 
+
 =back
 
 =cut
@@ -479,10 +487,14 @@ sub get_sources {
  return @{$self->{cash_sources}}; 
 }
 
+=over
+
 =item get_exchange_rate(currency, date)
 
 This method gets the exchange rate for the specified currency and date
 
+=back
+
 =cut 
 
 sub get_exchange_rate { 
@@ -493,9 +505,12 @@ sub get_exchange_rate {
  
 }
 
+=over
+
 =item get_default_currency
 
 This method gets the default currency 
+
 =back
 
 =cut
@@ -506,10 +521,14 @@ sub get_default_currency {
  return $self->{default_currency}->{defaults_get_defaultcurrency};
 }
 
+=over
+
 =item get_current_date
 
 This method returns the system's current date
 
+=back
+
 =cut
 
 sub get_current_date {
@@ -517,11 +536,15 @@ sub get_current_date {
  return $self->{current_date}; 
 }
 
+=over
+
 =item get_vc_info
 
 This method returns the contact informatino for a customer or vendor according to
 $self->{account_class}
 
+=back
+
 =cut
 
 sub get_vc_info {
@@ -533,10 +556,14 @@ sub get_vc_info {
  return ${$self->{vendor_customer_info}}[0];
 }
 
+=over
+
 =item get_payment_detail_data
 
 This method sets appropriate project, department, etc. fields.
 
+=back
+
 =cut
 
 sub get_payment_detail_data {
@@ -598,6 +625,8 @@ sub get_payment_detail_data {
     $self->{dbh}->commit; # Commit locks
 }    
 
+=over
+
 =item post_bulk
 
 This function posts the payments in bulk.  Note that queue_payments is not a 
@@ -621,6 +650,8 @@ associated with the current contact.  We will call this $contact_id below.
 
 For each contact id, we have the following, suffixed with _$contact_id:
 
+=back
+
 =over
 
 =item source
@@ -714,10 +745,14 @@ sub post_bulk {
     return $self->{dbh}->commit;
 }
 
+=over
+
 =item check_job
 
 To be moved into payment_queue addon.
 
+=back
+
 =cut
 
 sub check_job {
@@ -725,16 +760,21 @@ sub check_job {
     ($self->{job}) = $self->exec_method(funcname => 'job__status');
 }
 
+=over
+
 =item post_payment
 
 This method uses payment_post to store a payment (not a bulk payment) on the database.
 
+=back
+
 =cut
 
 sub post_payment {
  my ($self) = @_;
  # We have to check if it was a fx_payment
  $self->{currency} = $self->{curr};
+ $_ = "$_" for $self->_parse_array($self->{amount});
 
 
  if ("$self->{currency}" ne $self->get_default_currency()) {
@@ -754,17 +794,24 @@ sub post_payment {
    $self->error($self->{_locale}->text("Exchange rate inconsistency with database.  Got [_1], expected [_2]", $self->{exrate}, $db_exchangerate));
    }
  }
+ for (@{$self->{amount}}){
+    $_ = $_->bstr if ref $_;
+ }
  my @TMParray = $self->exec_method(funcname => 'payment_post');
  $self->{dbh}->commit();
  $self->{payment_id} = $TMParray[0]->{payment_post};
  return $self->{payment_id};
 }
 
+=over
+
 =item gather_printable_info 
 
 This method retrieves all the payment related info needed to build a
 document and print it. IT IS NECESSARY TO ALREADY HAVE payment_id on $self
 
+=back
+
 =cut
 
 
@@ -777,11 +824,15 @@ for my $row(@{$self->{line_info}}){
 }
 }
 
+=over
+
 =item get_open_overpayment_entities 
 
 This method retrieves all the entities with the specified
 account_class which have unused overpayments
 
+=back
+
 =cut
 
 sub get_open_overpayment_entities {
@@ -790,10 +841,14 @@ my ($self) = @_;
 return @{$self->{open_overpayment_entities}}; 
 }
 
+=over
+
 =item get_unused_overpayments
 
 This is a simple wrapper around payment_get_unused_overpayments sql function.
 
+=back
+
 =cut
 
 sub get_unused_overpayments {
@@ -802,10 +857,14 @@ my ($self) = @_;
 return @{$self->{unused_overpayment}}; 
 }
 
+=over
+
 =item get_available_overpayment_amount
 
 Simple wrapper around payment_get_available_overpayment_amount sql function.
 
+=back
+
 =cut
 
 sub get_available_overpayment_amount {
@@ -814,6 +873,8 @@ my ($self) = @_;
 return @{$self->{available_overpayment_amount}};
 }
 
+=over
+
 =item init
 
 Initializes the num2text system
@@ -822,6 +883,9 @@ Initializes the num2text system
 
 Translates numbers into words.
 
+=back
+
+
 =cut
 
 1;
